==> CSBS-VBS-Upgrade-Plugin-8.3.0.zip: CSBS/scripts/cipher_change/karbor/sub_job_rollback_cipher_type.py <==
import utils.common.log as logger
from utils.common.exception import HCCIException
from utils.common.message import Message

from plugins.CSBS.common.step_base import UpgradeBaseSubJob
from plugins.CSBS.common.upgrade.karbor import KarborOperation
from plugins.CSBS.common.upgrade.params import ParamsTools


logger.init("CSBS-VBS")


class RollbackCipherType(UpgradeBaseSubJob):
    def __init__(self, project_id, pod_id, regionid_list):
        super(RollbackCipherType, self).__init__(project_id, pod_id,
                                                 regionid_list)
        self.karbor_operation = KarborOperation(self.project_id)
        self.param_tool = ParamsTools(project_id)

    def execute(self, project_id, pod_id, regionid_list=None):
        """Plug-in internal interface.

        Perform installation & configuration.
        """
        cipher_type = self.param_tool.get_cipher_type()
        # Switch OS cipher type
        self.karbor_operation.switch_os_cipher(cipher_type.cur_cipher_type)
        try:
            result = self.karbor_operation.change_cipher_type(cipher_type.cur_cipher_type)
        except Exception as e:
            logger.error(f"Execute error:{e}.")
            return Message(500, HCCIException(645041, str(e)))
        if not result:
            logger.error("Failed to switch the cipher type on the Karbor node. "
                         f"The cipher type to be switched is {cipher_type.cur_cipher_type}.")
            return Message(500, HCCIException(645040, cipher_type.cur_cipher_type))
        karbor_cipher_type = self.karbor_operation.get_cipher_type()
        if karbor_cipher_type != cipher_type.cur_cipher_type:
            raise Exception(f"The cipher type of the CSBS-VBS karbor node "
                            f"is different from that of the target cipher "
                            f"type, karbor cipher type "
                            f"is: {karbor_cipher_type}, target cipher "
                            f"type is: {cipher_type.cur_cipher_type}.")

        logger.info("The cipher type has been switched successfully.")
        return Message(200)

==> CSBS-VBS-Upgrade-Plugin-8.3.1.zip: CSBS/scripts/cipher_change/karbor/sub_job_rollback_cipher_type.py <==
import utils.common.log as logger
from utils.common.exception import HCCIException
from utils.common.message import Message

from plugins.CSBS.common.step_base import UpgradeBaseSubJob
from plugins.CSBS.common.upgrade.karbor import KarborOperation
from plugins.CSBS.common.upgrade.params import ParamsTools


logger.init("CSBS-VBS")


class RollbackCipherType(UpgradeBaseSubJob):
    def __init__(self, project_id, pod_id, regionid_list):
        super(RollbackCipherType, self).__init__(project_id, pod_id,
                                                 regionid_list)
        self.karbor_operation = KarborOperation(self.project_id)
        self.param_tool = ParamsTools(project_id)

    def execute(self, project_id, pod_id, regionid_list=None):
        """Plug-in internal interface.

        Perform installation & configuration.
        """
        cipher_type = self.param_tool.get_cipher_type()
        # Switch OS cipher type
        self.karbor_operation.switch_os_cipher(cipher_type.cur_cipher_type)
        try:
            result = self.karbor_operation.change_cipher_type(cipher_type.cur_cipher_type)
        except Exception as err:
            logger.error(f"Execute error:{err}.")
            return Message(500, HCCIException(645041, str(err)))
        if not result:
            logger.error("Failed to switch the cipher type on the Karbor node. "
                         f"The cipher type to be switched is {cipher_type.cur_cipher_type}.")
            return Message(500, HCCIException(645040, cipher_type.cur_cipher_type))
        karbor_cipher_type = self.karbor_operation.get_cipher_type()
        if karbor_cipher_type != cipher_type.cur_cipher_type:
            raise Exception(f"The cipher type of the CSBS-VBS karbor node "
                            f"is different from that of the target cipher "
                            f"type, karbor cipher type "
                            f"is: {karbor_cipher_type}, target cipher "
                            f"type is: {cipher_type.cur_cipher_type}.")

        logger.info("The cipher type has been switched successfully.")
        return Message(200)
